import { realmPlugin } from "../../RealmWithPlugins.js";
import { Cell, Signal, map } from "@mdxeditor/gurx";
import { insertCodeBlock$, appendCodeBlockEditorDescriptor$ } from "../codeblock/index.js";
import { CodeMirrorEditor } from "./CodeMirrorEditor.js";
const codeBlockLanguages$ = Cell({
  js: "JavaScript",
  ts: "TypeScript",
  tsx: "TypeScript (React)",
  jsx: "JavaScript (React)",
  css: "CSS"
});
const insertCodeMirror$ = Signal((r) => {
  r.link(
    r.pipe(
      insertCodeMirror$,
      map(({ language, code }) => {
        return {
          code,
          language,
          meta: ""
        };
      })
    ),
    insertCodeBlock$
  );
});
const codeMirrorPlugin = realmPlugin({
  update(r, params) {
    r.pub(codeBlockLanguages$, params == null ? void 0 : params.codeBlockLanguages);
  },
  init(r, params) {
    r.pub(appendCodeBlockEditorDescriptor$, {
      match(language, meta) {
        return Boolean(params == null ? void 0 : params.codeBlockLanguages.hasOwnProperty(language)) && meta === "";
      },
      priority: 1,
      Editor: CodeMirrorEditor
    });
  }
});
export {
  codeBlockLanguages$,
  codeMirrorPlugin,
  insertCodeMirror$
};
